package com.bocloud.ims.interfaces.resource;

import com.alibaba.fastjson.JSONObject;
import com.bocloud.common.model.BocloudResult;
import com.bocloud.common.model.RequestContext;

public interface RosProcessService {

	public void createServer(String params, RequestContext context, String queue);

	public void createVolume(String params, RequestContext context, String queue);

	public void createRouter(String params, RequestContext context, String queue);

	public void createSecGroup(String params, RequestContext context, String queue);

	public void createFirewall(String params, RequestContext context, String queue);

	public void createSubnet(String params, RequestContext context, String queue);

	public void createNetwork(String params, RequestContext context, String queue);
	
	public void createFirewallPolicy(String params, RequestContext context, String queue);

	public void createFirewallRule(String params, RequestContext context, String queue);

	public void createLoadBalancer(String params, RequestContext context, String queue);

	public void createListener(String params, RequestContext context, String queue);

	public void createLbMember(String params, RequestContext context, String queue);

	public void createSecGroupRule(String params, RequestContext context, String queue);


	public BocloudResult createK8sVm(JSONObject params);

	public BocloudResult createVip(String params, RequestContext context, String queue);

}
